@@ -4,7 +4,7 @@
  *
  * Copyright © 1994,1995 Ian Jackson <ian@chiark.greenend.org.uk>
  * Copyright © 2000,2001 Wichert Akkerman <wakkerma@debian.org>
- * Copyright © 2007-2014 Guillem Jover <guillem@debian.org>
+ * Copyright © 2007-2015 Guillem Jover <guillem@debian.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,7 +29,6 @@
 
 #include <errno.h>
 #include <limits.h>
-#include <ctype.h>
 #include <string.h>
 #include <dirent.h>
 #include <fcntl.h>
@@ -40,6 +39,7 @@
 #include <stdio.h>
 
 #include <dpkg/i18n.h>
+#include <dpkg/c-ctype.h>
 #include <dpkg/dpkg.h>
 #include <dpkg/dpkg-db.h>
 #include <dpkg/path.h>
@@ -183,7 +183,7 @@ file_treewalk_feed(const char *dir, int fd_out)
     close(pipefd[1]);
 
     if (chdir(dir))
-      ohshite(_("failed to chdir to `%.255s'"), dir);
+      ohshite(_("failed to chdir to '%.255s'"), dir);
 
     execlp(FIND, "find", ".", "-path", "./" BUILDCONTROLDIR, "-prune", "-o",
            "-print0", NULL);
@@ -194,6 +194,8 @@ file_treewalk_feed(const char *dir, int fd_out)
   /* We need to reorder the files so we can make sure that symlinks
    * will not appear before their target. */
   while ((fi = file_info_get(dir, pipefd[0])) != NULL) {
+    if (strchr(fi->fn, '\n'))
+      ohshit(_("newline not allowed in pathname '%s'"), fi->fn);
     if (S_ISLNK(fi->st.st_mode)) {
       file_info_list_append(&symlist, &symlist_end, fi);
     } else {
@@ -249,14 +251,14 @@ check_file_perms(const char *dir)
       if (S_ISLNK(mscriptstab.st_mode))
         continue;
       if (!S_ISREG(mscriptstab.st_mode))
-        ohshit(_("maintainer script `%.50s' is not a plain file or symlink"),
+        ohshit(_("maintainer script '%.50s' is not a plain file or symlink"),
                *mscriptp);
       if ((mscriptstab.st_mode & 07557) != 0555)
-        ohshit(_("maintainer script `%.50s' has bad permissions %03lo "
+        ohshit(_("maintainer script '%.50s' has bad permissions %03lo "
                  "(must be >=0555 and <=0775)"),
                *mscriptp, (unsigned long)(mscriptstab.st_mode & 07777));
     } else if (errno != ENOENT) {
-      ohshite(_("maintainer script `%.50s' is not stattable"), *mscriptp);
+      ohshite(_("maintainer script '%.50s' is not stattable"), *mscriptp);
     }
   }
 
@@ -302,12 +304,12 @@ check_conffiles(const char *dir)
     varbuf_printf(&controlfile, "%s/%s", dir, conffilename);
     if (lstat(controlfile.buf, &controlstab)) {
       if (errno == ENOENT) {
-        if ((n > 1) && isspace(conffilename[n - 2]))
+        if ((n > 1) && c_isspace(conffilename[n - 2]))
           warning(_("conffile filename '%s' contains trailing white spaces"),
                   conffilename);
-        ohshit(_("conffile `%.250s' does not appear in package"), conffilename);
+        ohshit(_("conffile '%.250s' does not appear in package"), conffilename);
       } else
-        ohshite(_("conffile `%.250s' is not stattable"), conffilename);
+        ohshite(_("conffile '%.250s' is not stattable"), conffilename);
     } else if (!S_ISREG(controlstab.st_mode)) {
       warning(_("conffile '%s' is not a plain file"), conffilename);
     }
@@ -331,30 +333,46 @@ check_conffiles(const char *dir)
 }
 
 /**
- * Perform some sanity checks on the to-be-built package.
+ * Check the control file.
  *
- * @return The pkginfo struct from the parsed control file.
+ * @param dir	The directory from where to build the binary package.
+ * @return	The pkginfo struct from the parsed control file.
  */
 static struct pkginfo *
-check_new_pkg(const char *dir)
+check_control_file(const char *dir)
 {
   struct pkginfo *pkg;
   char *controlfile;
-  int warns;
 
-  /* Start by reading in the control file so we can check its contents. */
   m_asprintf(&controlfile, "%s/%s/%s", dir, BUILDCONTROLDIR, CONTROLFILE);
   parsedb(controlfile, pdb_parse_binary, &pkg);
 
   if (strspn(pkg->set->name, "abcdefghijklmnopqrstuvwxyz0123456789+-.") !=
       strlen(pkg->set->name))
-    ohshit(_("package name has characters that aren't lowercase alphanums or `-+.'"));
+    ohshit(_("package name has characters that aren't lowercase alphanums or '-+.'"));
   if (pkg->priority == PKG_PRIO_OTHER)
     warning(_("'%s' contains user-defined Priority value '%s'"),
             controlfile, pkg->otherpriority);
 
   free(controlfile);
 
+  return pkg;
+}
+
+/**
+ * Perform some sanity checks on the to-be-built package control area.
+ *
+ * @param dir	The directory from where to build the binary package.
+ * @return	The pkginfo struct from the parsed control file.
+ */
+static struct pkginfo *
+check_control_area(const char *dir)
+{
+  struct pkginfo *pkg;
+  int warns;
+
+  /* Start by reading in the control file so we can check its contents. */
+  pkg = check_control_file(dir);
   check_file_perms(dir);
   check_conffiles(dir);
 
@@ -368,19 +386,61 @@ check_new_pkg(const char *dir)
 }
 
 /**
- * Generate the pathname for the to-be-built package.
+ * Generate the pathname for the destination binary package.
+ *
+ * If the pathname cannot be computed, because the destination is a directory,
+ * then NULL will be returned.
+ *
+ * @param dir	The directory from where to build the binary package.
+ * @param dest	The destination name, either a file or directory name.
+ * @return	The pathname for the package being built.
+ */
+static char *
+gen_dest_pathname(const char *dir, const char *dest)
+{
+  if (dest) {
+    struct stat dest_stab;
+
+    if (stat(dest, &dest_stab)) {
+      if (errno != ENOENT)
+        ohshite(_("unable to check for existence of archive '%.250s'"), dest);
+    } else if (S_ISDIR(dest_stab.st_mode)) {
+      /* Need to compute the destination name from the package control file. */
+      return NULL;
+    }
+
+    return m_strdup(dest);
+  } else {
+    char *pathname;
+
+    pathname = m_malloc(strlen(dir) + sizeof(DEBEXT));
+    strcpy(pathname, dir);
+    path_trim_slash_slashdot(pathname);
+    strcat(pathname, DEBEXT);
+
+    return pathname;
+  }
+}
+
+/**
+ * Generate the pathname for the destination binary package from control file.
  *
  * @return The pathname for the package being built.
  */
 static char *
-pkg_get_pathname(const char *dir, struct pkginfo *pkg)
+gen_dest_pathname_from_pkg(const char *dir, struct pkginfo *pkg)
 {
+  const char *arch_sep;
   char *path;
-  const char *versionstring, *arch_sep;
 
-  versionstring = versiondescribe(&pkg->available.version, vdew_never);
-  arch_sep = pkg->available.arch->type == DPKG_ARCH_NONE ? "" : "_";
-  m_asprintf(&path, "%s/%s_%s%s%s%s", dir, pkg->set->name, versionstring,
+  if (pkg->available.arch->type == DPKG_ARCH_NONE ||
+      pkg->available.arch->type == DPKG_ARCH_EMPTY)
+    arch_sep = "";
+  else
+    arch_sep = "_";
+
+  m_asprintf(&path, "%s/%s_%s%s%s%s", dir, pkg->set->name,
+             versiondescribe(&pkg->available.version, vdew_never),
              arch_sep, pkg->available.arch->name, DEBEXT);
 
   return path;
@@ -394,8 +454,8 @@ do_build(const char *const *argv)
 {
   struct compress_params control_compress_params;
   struct dpkg_error err;
-  const char *debar, *dir;
-  bool subdir;
+  const char *dir, *dest;
+  char *debar;
   char *tfbuf;
   int arfd;
   int p1[2], p2[2], gzfd;
@@ -405,43 +465,26 @@ do_build(const char *const *argv)
   dir = *argv++;
   if (!dir)
     badusage(_("--%s needs a <directory> argument"), cipaction->olong);
-  subdir = false;
-  debar = *argv++;
-  if (debar != NULL) {
-    struct stat debarstab;
 
-    if (*argv)
-      badusage(_("--%s takes at most two arguments"), cipaction->olong);
+  dest = *argv++;
+  if (dest && *argv)
+    badusage(_("--%s takes at most two arguments"), cipaction->olong);
 
-    if (stat(debar, &debarstab)) {
-      if (errno != ENOENT)
-        ohshite(_("unable to check for existence of archive `%.250s'"), debar);
-    } else if (S_ISDIR(debarstab.st_mode)) {
-      subdir = true;
-    }
-  } else {
-    char *m;
-
-    m= m_malloc(strlen(dir) + sizeof(DEBEXT));
-    strcpy(m, dir);
-    path_trim_slash_slashdot(m);
-    strcat(m, DEBEXT);
-    debar= m;
-  }
+  debar = gen_dest_pathname(dir, dest);
 
   /* Perform some sanity checks on the to-be-build package. */
   if (nocheckflag) {
-    if (subdir)
+    if (debar == NULL)
       ohshit(_("target is directory - cannot skip control file check"));
     warning(_("not checking contents of control area"));
     printf(_("dpkg-deb: building an unknown package in '%s'.\n"), debar);
   } else {
     struct pkginfo *pkg;
 
-    pkg = check_new_pkg(dir);
-    if (subdir)
-      debar = pkg_get_pathname(debar, pkg);
-    printf(_("dpkg-deb: building package `%s' in `%s'.\n"),
+    pkg = check_control_area(dir);
+    if (debar == NULL)
+      debar = gen_dest_pathname_from_pkg(dest, pkg);
+    printf(_("dpkg-deb: building package '%s' in '%s'.\n"),
            pkg->set->name, debar);
   }
   m_output(stdout, _("<standard output>"));
@@ -450,7 +493,7 @@ do_build(const char *const *argv)
    * build something. Let's start by making the ar-wrapper. */
   arfd = creat(debar, 0644);
   if (arfd < 0)
-    ohshite(_("unable to create `%.255s'"), debar);
+    ohshite(_("unable to create '%.255s'"), debar);
   /* Fork a tar to package the control-section of the package. */
   unsetenv("TAR_OPTIONS");
   m_pipe(p1);
@@ -458,9 +501,9 @@ do_build(const char *const *argv)
   if (!c1) {
     m_dup2(p1[1],1); close(p1[0]); close(p1[1]);
     if (chdir(dir))
-      ohshite(_("failed to chdir to `%.255s'"), dir);
+      ohshite(_("failed to chdir to '%.255s'"), dir);
     if (chdir(BUILDCONTROLDIR))
-      ohshite(_("failed to chdir to `%.255s'"), ".../DEBIAN");
+      ohshite(_("failed to chdir to '%.255s'"), ".../DEBIAN");
     execlp(TAR, "tar", "-cf", "-", "--format=gnu", ".", NULL);
     ohshite(_("unable to execute %s (%s)"), "tar -cf", TAR);
   }
@@ -484,6 +527,8 @@ do_build(const char *const *argv)
     control_compress_params.type = COMPRESSOR_TYPE_GZIP;
     control_compress_params.strategy = COMPRESSOR_STRATEGY_NONE;
     control_compress_params.level = -1;
+    if (!compressor_check_params(&control_compress_params, &err))
+      internerr("invalid control member compressor params: %s", err.str);
   }
 
   c2 = subproc_fork();
@@ -492,7 +537,7 @@ do_build(const char *const *argv)
     exit(0);
   }
   close(p1[0]);
-  subproc_reap(c2, "gzip -9c", 0);
+  subproc_reap(c2, _("<compress> from tar -cf"), 0);
   subproc_reap(c1, "tar -cf", 0);
 
   if (lseek(gzfd, 0, SEEK_SET))
@@ -509,7 +554,7 @@ do_build(const char *const *argv)
     sprintf(versionbuf, "%-8s\n%jd\n", OLDARCHIVEVERSION,
             (intmax_t)controlstab.st_size);
     if (fd_write(arfd, versionbuf, strlen(versionbuf)) < 0)
-      ohshite(_("error writing `%s'"), debar);
+      ohshite(_("error writing '%s'"), debar);
     if (fd_fd_copy(gzfd, arfd, -1, &err) < 0)
       ohshit(_("cannot copy '%s' into archive '%s': %s"), _("control member"),
              debar, err.str);
@@ -558,9 +603,9 @@ do_build(const char *const *argv)
     m_dup2(p1[0],0); close(p1[0]); close(p1[1]);
     m_dup2(p2[1],1); close(p2[0]); close(p2[1]);
     if (chdir(dir))
-      ohshite(_("failed to chdir to `%.255s'"), dir);
+      ohshite(_("failed to chdir to '%.255s'"), dir);
     execlp(TAR, "tar", "-cf", "-", "--format=gnu", "--null", "--no-unquote",
-                       "--no-recursion", "-T", "-", NULL);
+                       "-T", "-", "--no-recursion", NULL);
     ohshite(_("unable to execute %s (%s)"), "tar -cf", TAR);
   }
   close(p1[0]);
@@ -578,7 +623,7 @@ do_build(const char *const *argv)
    * filenames to tar. */
   file_treewalk_feed(dir, p1[1]);
 
-  /* All done, clean up wait for tar and gzip to finish their job. */
+  /* All done, clean up wait for tar and <compress> to finish their job. */
   close(p1[1]);
   subproc_reap(c2, _("<compress> from tar -cf"), 0);
   subproc_reap(c1, "tar -cf", 0);
@@ -601,5 +646,7 @@ do_build(const char *const *argv)
   if (close(arfd))
     ohshite(_("unable to close file '%s'"), debar);
 
+  free(debar);
+
   return 0;
 }
