@@ -4,6 +4,7 @@
  *
  * Copyright © 1994,1995 Ian Jackson <ian@chiark.greenend.org.uk>
  * Copyright © 2001 Wichert Akkerman
+ * Copyright © 2007-2015 Guillem Jover <guillem@debian.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,7 +29,6 @@
 
 #include <errno.h>
 #include <limits.h>
-#include <ctype.h>
 #include <string.h>
 #include <fcntl.h>
 #include <dirent.h>
@@ -38,34 +38,23 @@
 #include <stdio.h>
 
 #include <dpkg/i18n.h>
+#include <dpkg/c-ctype.h>
 #include <dpkg/dpkg.h>
 #include <dpkg/dpkg-db.h>
 #include <dpkg/parsedump.h>
 #include <dpkg/pkg-format.h>
 #include <dpkg/buffer.h>
 #include <dpkg/path.h>
-#include <dpkg/subproc.h>
 #include <dpkg/options.h>
 
 #include "dpkg-deb.h"
 
 static void cu_info_prepare(int argc, void **argv) {
-  pid_t pid;
   char *dir;
-  struct stat stab;
 
   dir = argv[0];
-  if (lstat(dir, &stab) && errno == ENOENT)
-    return;
-
-  pid = subproc_fork();
-  if (pid == 0) {
-    if (chdir("/"))
-      ohshite(_("failed to chdir to `/' for cleanup"));
-    execlp(RM, "rm", "-rf", dir, NULL);
-    ohshite(_("unable to execute %s (%s)"), _("rm command for cleanup"), RM);
-  }
-  subproc_reap(pid, _("rm command for cleanup"), 0);
+  path_remove_tree(dir);
+  free(dir);
 }
 
 static void info_prepare(const char *const **argvp,
@@ -114,7 +103,7 @@ info_spew(const char *debar, const char *dir, const char *const *argv)
              debar, component);
       re++;
     } else {
-      ohshite(_("open component `%.255s' (in %.255s) failed in an unexpected way"),
+      ohshite(_("open component '%.255s' (in %.255s) failed in an unexpected way"),
               component, dir);
     }
   }
@@ -139,7 +128,7 @@ info_list(const char *debar, const char *dir)
 
   cdn = scandir(dir, &cdlist, &ilist_select, alphasort);
   if (cdn == -1)
-    ohshite(_("cannot scan directory `%.255s'"), dir);
+    ohshite(_("cannot scan directory '%.255s'"), dir);
 
   for (n = 0; n < cdn; n++) {
     cdep = cdlist[n];
@@ -148,18 +137,18 @@ info_list(const char *debar, const char *dir)
     varbuf_printf(&controlfile, "%s/%s", dir, cdep->d_name);
 
     if (stat(controlfile.buf, &stab))
-      ohshite(_("cannot stat `%.255s' (in `%.255s')"), cdep->d_name, dir);
+      ohshite(_("cannot stat '%.255s' (in '%.255s')"), cdep->d_name, dir);
     if (S_ISREG(stab.st_mode)) {
       cc = fopen(controlfile.buf, "r");
       if (!cc)
-        ohshite(_("cannot open `%.255s' (in `%.255s')"), cdep->d_name, dir);
+        ohshite(_("cannot open '%.255s' (in '%.255s')"), cdep->d_name, dir);
       lines = 0;
       interpreter[0] = '\0';
       if (getc(cc) == '#') {
         if (getc(cc) == '!') {
           while ((c= getc(cc))== ' ');
           p=interpreter; *p++='#'; *p++='!'; il=2;
-          while (il<INTERPRETER_MAX && !isspace(c) && c!=EOF) {
+          while (il < INTERPRETER_MAX && !c_isspace(c) && c != EOF) {
             *p++= c; il++; c= getc(cc);
           }
           *p = '\0';
@@ -167,8 +156,8 @@ info_list(const char *debar, const char *dir)
         }
       }
       while ((c= getc(cc))!= EOF) { if (c == '\n') lines++; }
-      if (ferror(cc)) ohshite(_("failed to read `%.255s' (in `%.255s')"),
-                              cdep->d_name, dir);
+      if (ferror(cc))
+        ohshite(_("failed to read '%.255s' (in '%.255s')"), cdep->d_name, dir);
       fclose(cc);
       printf(_(" %7jd bytes, %5d lines   %c  %-20.127s %.127s\n"),
              (intmax_t)stab.st_size, lines, S_IXUSR & stab.st_mode ? '*' : ' ',
@@ -185,8 +174,8 @@ info_list(const char *debar, const char *dir)
   cc = fopen(controlfile.buf, "r");
   if (!cc) {
     if (errno != ENOENT)
-      ohshite(_("failed to read `%.255s' (in `%.255s')"), CONTROLFILE, dir);
-    fputs(_("(no `control' file in control archive!)\n"), stdout);
+      ohshite(_("failed to read '%.255s' (in '%.255s')"), CONTROLFILE, dir);
+    fputs(_("(no 'control' file in control archive!)\n"), stdout);
   } else {
     lines= 1;
     while ((c= getc(cc))!= EOF) {
@@ -199,7 +188,7 @@ info_list(const char *debar, const char *dir)
       putc('\n', stdout);
 
     if (ferror(cc))
-      ohshite(_("failed to read `%.255s' (in `%.255s')"), CONTROLFILE, dir);
+      ohshite(_("failed to read '%.255s' (in '%.255s')"), CONTROLFILE, dir);
     fclose(cc);
   }
 
