@@ -43,7 +43,7 @@ This object represents a changelog entry. It is composed
 of a set of lines with specific purpose: an header line, changes lines, a
 trailer line. Blank lines can be between those kind of lines.
 
-=head1 FUNCTIONS
+=head1 METHODS
 
 =over 4
 
@@ -55,7 +55,7 @@ until one has been successfully parsed or built from scratch.
 =cut
 
 sub new {
-    my ($this) = @_;
+    my $this = shift;
     my $class = ref($this) || $this;
 
     my $self = {
@@ -176,7 +176,7 @@ parts.
 =cut
 
 sub is_empty {
-    my ($self) = @_;
+    my $self = shift;
     return !(defined($self->{header}) || defined($self->{trailer}) ||
 	     scalar(@{$self->{changes}}));
 }
@@ -189,7 +189,7 @@ empty line to separate each part.
 =cut
 
 sub normalize {
-    my ($self) = @_;
+    my $self = shift;
     if (defined($self->{header})) {
 	$self->{header} =~ s/\s+$//g;
 	$self->{blank_after_header} = [''];
@@ -289,7 +289,7 @@ in the output format of C<dpkg-parsechangelog>.
 =cut
 
 sub get_dpkg_changes {
-    my ($self) = @_;
+    my $self = shift;
     my $header = $self->get_part('header') // '';
     $header =~ s/\s+$//;
     return "\n$header\n\n" . join("\n", @{$self->get_part('changes')});
@@ -297,6 +297,12 @@ sub get_dpkg_changes {
 
 =back
 
+=head1 CHANGES
+
+=head2 Version 1.00 (dpkg 1.15.6)
+
+Mark the module as public.
+
 =head1 AUTHOR
 
 Raphaël Hertzog <hertzog@debian.org>.
