@@ -20,20 +20,25 @@ use strict;
 use warnings;
 
 our $VERSION = '1.01';
+our @EXPORT_OK = qw(
+    $regex_header
+    $regex_trailer
+    match_header
+    match_trailer
+    find_closes
+);
 
 use Exporter qw(import);
-use Dpkg::Changelog::Entry;
-use parent qw(Dpkg::Changelog::Entry);
-our @EXPORT_OK = qw(match_header match_trailer find_closes
-                    $regex_header $regex_trailer);
-
 use Date::Parse;
 
 use Dpkg::Gettext;
 use Dpkg::Control::Fields;
 use Dpkg::Control::Changelog;
+use Dpkg::Changelog::Entry;
 use Dpkg::Version;
 
+use parent qw(Dpkg::Changelog::Entry);
+
 =encoding utf8
 
 =head1 NAME
@@ -63,7 +68,7 @@ our $regex_trailer = qr/^ \-\- (.*) <(.*)>(  ?)((\w+\,\s*)?\d{1,2}\s+\w+\s+\d{4}
 
 ## use critic
 
-=head1 FUNCTIONS
+=head1 METHODS
 
 =over 4
 
@@ -78,7 +83,7 @@ following line necessarily starts a new item).
 =cut
 
 sub get_change_items {
-    my ($self) = @_;
+    my $self = shift;
     my (@items, @blanks, $item);
     foreach my $line (@{$self->get_part('changes')}) {
 	if ($line =~ /^\s*\*/) {
@@ -115,7 +120,7 @@ have been found.
 =cut
 
 sub check_header {
-    my ($self) = @_;
+    my $self = shift;
     my @errors;
     if (defined($self->{header}) and $self->{header} =~ $regex_header) {
 	my ($version, $options) = ($2, $4);
@@ -123,47 +128,47 @@ sub check_header {
 	my %optdone;
 	foreach my $opt (split(/\s*,\s*/, $options)) {
 	    unless ($opt =~ m/^([-0-9a-z]+)\=\s*(.*\S)$/i) {
-		push @errors, sprintf(_g("bad key-value after \`;': \`%s'"), $opt);
+		push @errors, sprintf(g_("bad key-value after ';': '%s'"), $opt);
 		next;
 	    }
 	    my ($k, $v) = (field_capitalize($1), $2);
 	    if ($optdone{$k}) {
-		push @errors, sprintf(_g('repeated key-value %s'), $k);
+		push @errors, sprintf(g_('repeated key-value %s'), $k);
 	    }
 	    $optdone{$k} = 1;
 	    if ($k eq 'Urgency') {
-		push @errors, sprintf(_g('badly formatted urgency value: %s'), $v)
+		push @errors, sprintf(g_('badly formatted urgency value: %s'), $v)
 		    unless ($v =~ m/^([-0-9a-z]+)((\s+.*)?)$/i);
 	    } elsif ($k eq 'Binary-Only') {
-		push @errors, sprintf(_g('bad binary-only value: %s'), $v)
+		push @errors, sprintf(g_('bad binary-only value: %s'), $v)
 		    unless ($v eq 'yes');
 	    } elsif ($k =~ m/^X[BCS]+-/i) {
 	    } else {
-		push @errors, sprintf(_g('unknown key-value %s'), $k);
+		push @errors, sprintf(g_('unknown key-value %s'), $k);
 	    }
 	}
 	my ($ok, $msg) = version_check($version);
 	unless ($ok) {
-	    push @errors, sprintf(_g("version '%s' is invalid: %s"), $version, $msg);
+	    push @errors, sprintf(g_("version '%s' is invalid: %s"), $version, $msg);
 	}
     } else {
-	push @errors, _g("the header doesn't match the expected regex");
+	push @errors, g_("the header doesn't match the expected regex");
     }
     return @errors;
 }
 
 sub check_trailer {
-    my ($self) = @_;
+    my $self = shift;
     my @errors;
     if (defined($self->{trailer}) and $self->{trailer} =~ $regex_trailer) {
 	if ($3 ne '  ') {
-	    push @errors, _g('badly formatted trailer line');
+	    push @errors, g_('badly formatted trailer line');
 	}
 	unless (defined str2time($4)) {
-	    push @errors, sprintf(_g("couldn't parse date %s"), $4);
+	    push @errors, sprintf(g_("couldn't parse date %s"), $4);
 	}
     } else {
-	push @errors, _g("the trailer doesn't match the expected regex");
+	push @errors, g_("the trailer doesn't match the expected regex");
     }
     return @errors;
 }
@@ -176,13 +181,13 @@ empty line to separate each part.
 =cut
 
 sub normalize {
-    my ($self) = @_;
+    my $self = shift;
     $self->SUPER::normalize();
     #XXX: recreate header/trailer
 }
 
 sub get_source {
-    my ($self) = @_;
+    my $self = shift;
     if (defined($self->{header}) and $self->{header} =~ $regex_header) {
 	return $1;
     }
@@ -190,7 +195,7 @@ sub get_source {
 }
 
 sub get_version {
-    my ($self) = @_;
+    my $self = shift;
     if (defined($self->{header}) and $self->{header} =~ $regex_header) {
 	return Dpkg::Version->new($2);
     }
@@ -198,7 +203,7 @@ sub get_version {
 }
 
 sub get_distributions {
-    my ($self) = @_;
+    my $self = shift;
     if (defined($self->{header}) and $self->{header} =~ $regex_header) {
 	my $value = $3;
 	$value =~ s/^\s+//;
@@ -210,7 +215,7 @@ sub get_distributions {
 }
 
 sub get_optional_fields {
-    my ($self) = @_;
+    my $self = shift;
     my $f = Dpkg::Control::Changelog->new();
     if (defined($self->{header}) and $self->{header} =~ $regex_header) {
 	my $options = $4;
@@ -229,7 +234,7 @@ sub get_optional_fields {
 }
 
 sub get_urgency {
-    my ($self) = @_;
+    my $self = shift;
     my $f = $self->get_optional_fields();
     if (exists $f->{Urgency}) {
 	$f->{Urgency} =~ s/\s.*$//;
@@ -239,7 +244,7 @@ sub get_urgency {
 }
 
 sub get_maintainer {
-    my ($self) = @_;
+    my $self = shift;
     if (defined($self->{trailer}) and $self->{trailer} =~ $regex_trailer) {
 	return "$1 <$2>";
     }
@@ -247,7 +252,7 @@ sub get_maintainer {
 }
 
 sub get_timestamp {
-    my ($self) = @_;
+    my $self = shift;
     if (defined($self->{trailer}) and $self->{trailer} =~ $regex_trailer) {
 	return $4;
     }
@@ -267,7 +272,7 @@ Checks if the line matches a valid changelog header line.
 =cut
 
 sub match_header {
-    my ($line) = @_;
+    my $line = shift;
 
     return $line =~ /$regex_header/;
 }
@@ -279,7 +284,7 @@ Checks if the line matches a valid changelog trailing line.
 =cut
 
 sub match_trailer {
-    my ($line) = @_;
+    my $line = shift;
 
     return $line =~ /$regex_trailer/;
 }
@@ -309,13 +314,13 @@ sub find_closes {
 
 =head1 CHANGES
 
-=head2 Version 1.01
+=head2 Version 1.01 (dpkg 1.17.2)
 
 New functions: match_header(), match_trailer()
 
 Deprecated variables: $regex_header, $regex_trailer
 
-=head2 Version 1.00
+=head2 Version 1.00 (dpkg 1.15.6)
 
 Mark the module as public.
 
