@@ -1,5 +1,6 @@
 # Copyright © 2005, 2007 Frank Lichtenheld <frank@lichtenheld.de>
 # Copyright © 2009       Raphaël Hertzog <hertzog@debian.org>
+# Copyright © 2010, 2012-2015 Guillem Jover <guillem@debian.org>
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -25,8 +26,6 @@ Dpkg::Changelog::Parse - generic changelog parser for dpkg-parsechangelog
 This module provides a single function changelog_parse() which reproduces
 all the features of dpkg-parsechangelog.
 
-=head2 FUNCTIONS
-
 =cut
 
 package Dpkg::Changelog::Parse;
@@ -35,14 +34,18 @@ use strict;
 use warnings;
 
 our $VERSION = '1.00';
+our @EXPORT = qw(
+    changelog_parse
+);
+
+use Exporter qw(import);
 
 use Dpkg ();
 use Dpkg::Gettext;
 use Dpkg::ErrorHandling;
 use Dpkg::Control::Changelog;
 
-use Exporter qw(import);
-our @EXPORT = qw(changelog_parse);
+=head1 FUNCTIONS
 
 =over 4
 
@@ -103,11 +106,11 @@ sub changelog_parse {
 	local $_;
 
 	open(my $format_fh, '-|', 'tail', '-n', '40', $changelogfile)
-	    or syserr(_g('cannot create pipe for %s'), 'tail');
+	    or syserr(g_('cannot create pipe for %s'), 'tail');
 	while (<$format_fh>) {
 	    $format = $1 if m/\schangelog-format:\s+([0-9a-z]+)\W/;
 	}
-	close($format_fh) or subprocerr(_g('tail of %s'), $changelogfile);
+	close($format_fh) or subprocerr(g_('tail of %s'), $changelogfile);
     }
 
     # Find the right changelog parser
@@ -119,10 +122,10 @@ sub changelog_parse {
 	    $parser = $candidate;
 	    last;
 	} else {
-	    warning(_g('format parser %s not executable'), $candidate);
+	    warning(g_('format parser %s not executable'), $candidate);
 	}
     }
-    error(_g('changelog format %s is unknown'), $format) if not defined $parser;
+    error(g_('changelog format %s is unknown'), $format) if not defined $parser;
 
     # Create the arguments for the changelog parser
     my @exec = ($parser, "-l$changelogfile");
@@ -139,19 +142,19 @@ sub changelog_parse {
 
     # Fork and call the parser
     my $pid = open(my $parser_fh, '-|');
-    syserr(_g('cannot fork for %s'), $parser) unless defined $pid;
+    syserr(g_('cannot fork for %s'), $parser) unless defined $pid;
     if (not $pid) {
-	exec(@exec) or syserr(_g('cannot exec format parser: %s'), $parser);
+        exec @exec or syserr(g_('cannot execute format parser: %s'), $parser);
     }
 
     # Get the output into several Dpkg::Control objects
     my (@res, $fields);
     while (1) {
         $fields = Dpkg::Control::Changelog->new();
-        last unless $fields->parse($parser_fh, _g('output of changelog parser'));
+        last unless $fields->parse($parser_fh, g_('output of changelog parser'));
 	push @res, $fields;
     }
-    close($parser_fh) or subprocerr(_g('changelog parser %s'), $parser);
+    close($parser_fh) or subprocerr(g_('changelog parser %s'), $parser);
     if (wantarray) {
 	return @res;
     } else {
@@ -164,7 +167,7 @@ sub changelog_parse {
 
 =head1 CHANGES
 
-=head2 Version 1.00
+=head2 Version 1.00 (dpkg 1.15.6)
 
 Mark the module as public.
 
