@@ -1,5 +1,5 @@
 # Copyright © 2008 Frank Lichtenheld <djpig@debian.org>
-# Copyright © 2008, 2012-2014 Guillem Jover <guillem@debian.org>
+# Copyright © 2008, 2012-2015 Guillem Jover <guillem@debian.org>
 # Copyright © 2010 Raphaël Hertzog <hertzog@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -20,16 +20,19 @@ package Dpkg::Checksums;
 use strict;
 use warnings;
 
-our $VERSION = '1.01';
-
-use Dpkg;
-use Dpkg::Gettext;
-use Dpkg::ErrorHandling;
-use Dpkg::IPC;
+our $VERSION = '1.02';
+our @EXPORT = qw(
+    checksums_is_supported
+    checksums_get_list
+    checksums_get_property
+);
 
 use Exporter qw(import);
-our @EXPORT = qw(checksums_get_list checksums_is_supported
-		 checksums_get_property);
+use Carp;
+use Digest;
+
+use Dpkg::Gettext;
+use Dpkg::ErrorHandling;
 
 =encoding utf8
 
@@ -51,15 +54,15 @@ about supported checksums.
 
 my $CHECKSUMS = {
     md5 => {
-	program => [ 'md5sum' ],
+	name => 'MD5',
 	regex => qr/[0-9a-f]{32}/,
     },
     sha1 => {
-	program => [ 'sha1sum' ],
+	name => 'SHA-1',
 	regex => qr/[0-9a-f]{40}/,
     },
     sha256 => {
-	program => [ 'sha256sum' ],
+	name => 'SHA-256',
 	regex => qr/[0-9a-f]{64}/,
     },
 };
@@ -83,7 +86,7 @@ supported. The checksum algorithm is case-insensitive.
 =cut
 
 sub checksums_is_supported($) {
-    my ($alg) = @_;
+    my $alg = shift;
     return exists $CHECKSUMS->{lc($alg)};
 }
 
@@ -91,23 +94,22 @@ sub checksums_is_supported($) {
 
 Returns the requested property of the checksum algorithm. Returns undef if
 either the property or the checksum algorithm doesn't exist. Valid
-properties currently include "program" (returns an array reference with
-a program name and parameters required to compute the checksum of the
-filename given as last parameter) and "regex" for the regular expression
-describing the common string representation of the checksum (as output
-by the program that generates it).
+properties currently include "name" (returns the name of the digest
+algorithm) and "regex" for the regular expression describing the common
+string representation of the checksum.
 
 =cut
 
 sub checksums_get_property($$) {
     my ($alg, $property) = @_;
+    carp 'obsolete checksums program property' if $property eq 'program';
     return unless checksums_is_supported($alg);
     return $CHECKSUMS->{lc($alg)}{$property};
 }
 
 =back
 
-=head1 OBJECT METHODS
+=head1 METHODS
 
 =over 4
 
@@ -137,7 +139,8 @@ as if it was newly created.
 =cut
 
 sub reset {
-    my ($self) = @_;
+    my $self = shift;
+
     $self->{files} = [];
     $self->{checksums} = {};
     $self->{size} = {};
@@ -170,30 +173,27 @@ sub add_from_file {
     }
 
     push @{$self->{files}}, $key unless exists $self->{size}{$key};
-    (my @s = stat($file)) or syserr(_g('cannot fstat file %s'), $file);
+    (my @s = stat($file)) or syserr(g_('cannot fstat file %s'), $file);
     if (not $opts{update} and exists $self->{size}{$key} and
         $self->{size}{$key} != $s[7]) {
-	error(_g('file %s has size %u instead of expected %u'),
+	error(g_('file %s has size %u instead of expected %u'),
 	      $file, $s[7], $self->{size}{$key});
     }
     $self->{size}{$key} = $s[7];
 
     foreach my $alg (@alg) {
-	my @exec = (@{$CHECKSUMS->{$alg}{program}}, $file);
-	my $regex = $CHECKSUMS->{$alg}{regex};
-	my $output;
-	spawn(exec => \@exec, to_string => \$output);
-	if ($output =~ /^($regex)(\s|$)/m) {
-	    my $newsum = $1;
-	    if (not $opts{update} and exists $self->{checksums}{$key}{$alg} and
-		$self->{checksums}{$key}{$alg} ne $newsum) {
-		error(_g('file %s has checksum %s instead of expected %s (algorithm %s)'),
-		      $file, $newsum, $self->{checksums}{$key}{$alg}, $alg);
-	    }
-	    $self->{checksums}{$key}{$alg} = $newsum;
-	} else {
-	    error(_g("checksum program gave bogus output `%s'"), $output);
-	}
+        my $digest = Digest->new($CHECKSUMS->{$alg}{name});
+        open my $fh, '<', $file or syserr(g_('cannot open file %s'), $file);
+        $digest->addfile($fh);
+        close $fh;
+
+        my $newsum = $digest->hexdigest;
+        if (not $opts{update} and exists $self->{checksums}{$key}{$alg} and
+            $self->{checksums}{$key}{$alg} ne $newsum) {
+            error(g_('file %s has checksum %s instead of expected %s (algorithm %s)'),
+                  $file, $newsum, $self->{checksums}{$key}{$alg}, $alg);
+        }
+        $self->{checksums}{$key}{$alg} = $newsum;
     }
 }
 
@@ -221,18 +221,18 @@ sub add_from_string {
     for my $checksum (split /\n */, $fieldtext) {
 	next if $checksum eq '';
 	unless ($checksum =~ m/^($regex)\s+(\d+)\s+($rx_fname)$/) {
-	    error(_g('invalid line in %s checksums string: %s'),
+	    error(g_('invalid line in %s checksums string: %s'),
 		  $alg, $checksum);
 	}
 	my ($sum, $size, $file) = ($1, $2, $3);
 	if (not $opts{update} and  exists($checksums->{$file}{$alg})
 	    and $checksums->{$file}{$alg} ne $sum) {
-	    error(_g("conflicting checksums '%s' and '%s' for file '%s'"),
+	    error(g_("conflicting checksums '%s' and '%s' for file '%s'"),
 		  $checksums->{$file}{$alg}, $sum, $file);
 	}
 	if (not $opts{update} and exists $self->{size}{$file}
 	    and $self->{size}{$file} != $size) {
-	    error(_g("conflicting file sizes '%u' and '%u' for file '%s'"),
+	    error(g_("conflicting file sizes '%u' and '%u' for file '%s'"),
 		  $self->{size}{$file}, $size, $file);
 	}
 	push @{$self->{files}}, $file unless exists $self->{size}{$file};
@@ -272,7 +272,7 @@ Return the list of files whose checksums are stored in the object.
 =cut
 
 sub get_files {
-    my ($self) = @_;
+    my $self = shift;
     return @{$self->{files}};
 }
 
@@ -376,14 +376,22 @@ sub export_to_control {
 
 =head1 CHANGES
 
-=head2 Version 1.01
+=head2 Version 1.02 (dpkg 1.18.0)
+
+Obsolete property: Getting the 'program' checksum property will carp() and
+return undef, the Digest module is used internally now.
+
+New property: Add new 'name' property with the name of the Digest algorithm
+to use.
+
+=head2 Version 1.01 (dpkg 1.17.6)
 
 New argument: Accept an options argument in $ck->export_to_string().
 
 New option: Accept new option 'update' in $ck->add_from_file() and
 $ck->add_from_control().
 
-=head2 Version 1.00
+=head2 Version 1.00 (dpkg 1.15.6)
 
 Mark the module as public.
 
