@@ -1,4 +1,5 @@
 # Copyright © 2008-2010 Raphaël Hertzog <hertzog@debian.org>
+# Copyright © 2012-2014 Guillem Jover <guillem@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,16 +19,16 @@ package Dpkg::Compression::FileHandle;
 use strict;
 use warnings;
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
+
+use POSIX qw(:signal_h :sys_wait_h);
+use Carp;
 
 use Dpkg::Compression;
 use Dpkg::Compression::Process;
 use Dpkg::Gettext;
 use Dpkg::ErrorHandling;
 
-use Carp;
-use POSIX qw(:signal_h :sys_wait_h);
-
 use parent qw(FileHandle Tie::Handle);
 
 # Useful reference to understand some kludges required to
@@ -146,24 +147,31 @@ sub new {
     return $self;
 }
 
-=item $fh->ensure_open($mode)
+=item $fh->ensure_open($mode, %opts)
 
 Ensure the file is opened in the requested mode ("r" for read and "w" for
-write). Opens the file with the recorded filename if needed. If the file
+write). The options are passed down to the compressor's spawn() call, if one
+is used. Opens the file with the recorded filename if needed. If the file
 is already open but not in the requested mode, then it errors out.
 
 =cut
 
 sub ensure_open {
-    my ($self, $mode) = @_;
+    my ($self, $mode, %opts) = @_;
     if (exists *$self->{mode}) {
 	return if *$self->{mode} eq $mode;
 	croak "ensure_open requested incompatible mode: $mode";
     } else {
+	# Sanitize options.
+	delete $opts{from_pipe};
+	delete $opts{from_file};
+	delete $opts{to_pipe};
+	delete $opts{to_file};
+
 	if ($mode eq 'w') {
-	    $self->open_for_write();
+	    $self->open_for_write(%opts);
 	} elsif ($mode eq 'r') {
-	    $self->open_for_read();
+	    $self->open_for_read(%opts);
 	} else {
 	    croak "invalid mode in ensure_open: $mode";
 	}
@@ -355,7 +363,7 @@ method.
 =cut
 
 sub use_compression {
-    my ($self) = @_;
+    my $self = shift;
     my $comp = *$self->{compression};
     if ($comp eq 'none') {
 	return 0;
@@ -374,14 +382,14 @@ along in a derived object.
 =cut
 
 sub get_filehandle {
-    my ($self) = @_;
+    my $self = shift;
     return *$self->{file} if exists *$self->{file};
 }
 
 ## INTERNAL METHODS
 
 sub open_for_write {
-    my ($self) = @_;
+    my ($self, %opts) = @_;
     my $filehandle;
 
     croak 'cannot reopen an already opened compressed file'
@@ -389,17 +397,17 @@ sub open_for_write {
 
     if ($self->use_compression()) {
 	*$self->{compressor}->compress(from_pipe => \$filehandle,
-		to_file => $self->get_filename());
+		to_file => $self->get_filename(), %opts);
     } else {
 	CORE::open($filehandle, '>', $self->get_filename)
-	    or syserr(_g('cannot write %s'), $self->get_filename());
+	    or syserr(g_('cannot write %s'), $self->get_filename());
     }
     *$self->{mode} = 'w';
     *$self->{file} = $filehandle;
 }
 
 sub open_for_read {
-    my ($self) = @_;
+    my ($self, %opts) = @_;
     my $filehandle;
 
     croak 'cannot reopen an already opened compressed file'
@@ -407,19 +415,19 @@ sub open_for_read {
 
     if ($self->use_compression()) {
 	*$self->{compressor}->uncompress(to_pipe => \$filehandle,
-		from_file => $self->get_filename());
+		from_file => $self->get_filename(), %opts);
         *$self->{allow_sigpipe} = 1;
     } else {
 	CORE::open($filehandle, '<', $self->get_filename)
-	    or syserr(_g('cannot read %s'), $self->get_filename());
+	    or syserr(g_('cannot read %s'), $self->get_filename());
     }
     *$self->{mode} = 'r';
     *$self->{file} = $filehandle;
 }
 
 sub cleanup {
-    my ($self) = @_;
-    my $cmdline = *$self->{compressor}{cmdline} || '';
+    my $self = shift;
+    my $cmdline = *$self->{compressor}{cmdline} // '';
     *$self->{compressor}->wait_end_process(nocheck => *$self->{allow_sigpipe});
     if (*$self->{allow_sigpipe}) {
         unless (($? == 0) || (WIFSIGNALED($?) && (WTERMSIG($?) == SIGPIPE))) {
@@ -448,6 +456,15 @@ C<*$self->{...}> to access the associated hash like in the example below:
 	*$self->{option} = $value;
     }
 
+=head1 CHANGES
+
+=head2 Version 1.01 (dpkg 1.17.11)
+
+New argument: $fh->ensure_open() accepts an %opts argument.
+
+=head2 Version 1.00 (dpkg 1.15.6)
+
+Mark the module as public.
 
 =head1 AUTHOR
 
