@@ -19,22 +19,33 @@ use strict;
 use warnings;
 
 our $VERSION = '1.00';
+our @EXPORT = qw(
+    field_capitalize
+    field_is_official
+    field_is_allowed_in
+    field_transfer_single
+    field_transfer_all
+    field_list_src_dep
+    field_list_pkg_dep
+    field_get_dep_type
+    field_get_sep_type
+    field_ordered_list
+    field_register
+    field_insert_after
+    field_insert_before
+    FIELD_SEP_UNKNOWN
+    FIELD_SEP_SPACE
+    FIELD_SEP_COMMA
+    FIELD_SEP_LINE
+);
 
 use Exporter qw(import);
+
 use Dpkg::Gettext;
 use Dpkg::ErrorHandling;
 use Dpkg::Control::Types;
 use Dpkg::Checksums;
 
-our @EXPORT = qw(field_capitalize field_is_official field_is_allowed_in
-                 field_transfer_single field_transfer_all
-                 field_list_src_dep field_list_pkg_dep field_get_dep_type
-                 field_get_sep_type
-                 field_ordered_list field_register
-                 field_insert_after field_insert_before
-                 FIELD_SEP_UNKNOWN FIELD_SEP_SPACE FIELD_SEP_COMMA
-                 FIELD_SEP_LINE);
-
 use constant {
     ALL_PKG => CTRL_INFO_PKG | CTRL_INDEX_PKG | CTRL_PKG_DEB | CTRL_FILE_STATUS,
     ALL_SRC => CTRL_INFO_SRC | CTRL_INDEX_SRC | CTRL_PKG_SRC,
@@ -506,8 +517,8 @@ sub field_transfer_single($$;$) {
 	    return $field;
 	}
     } elsif (not field_is_allowed_in($field, $from_type)) {
-        warning(_g("unknown information field '%s' in input data in %s"),
-                $field, $from->get_option('name') || _g('control information'));
+        warning(g_("unknown information field '%s' in input data in %s"),
+                $field, $from->get_option('name') || g_('control information'));
     }
     return;
 }
@@ -540,7 +551,7 @@ The list might be empty for types where the order does not matter much.
 =cut
 
 sub field_ordered_list($) {
-    my ($type) = @_;
+    my $type = shift;
     return @{$FIELD_ORDER{$type}} if exists $FIELD_ORDER{$type};
     return ();
 }
@@ -664,7 +675,7 @@ sub field_insert_before($$@) {
 
 =head1 CHANGES
 
-=head2 Version 1.00
+=head2 Version 1.00 (dpkg 1.17.0)
 
 Mark the module as public.
 
