@@ -3,7 +3,7 @@
  * main.c - main program
  *
  * Copyright © 1994,1995 Ian Jackson <ian@chiark.greenend.org.uk>
- * Copyright © 2006-2014 Guillem Jover <guillem@debian.org>
+ * Copyright © 2006-2015 Guillem Jover <guillem@debian.org>
  * Copyright © 2010 Canonical Ltd.
  *   written by Martin Pitt <martin.pitt@canonical.com>
  *
@@ -32,7 +32,6 @@
 #if HAVE_LOCALE_H
 #include <locale.h>
 #endif
-#include <ctype.h>
 #include <string.h>
 #include <fcntl.h>
 #include <dirent.h>
@@ -43,6 +42,7 @@
 
 #include <dpkg/macros.h>
 #include <dpkg/i18n.h>
+#include <dpkg/c-ctype.h>
 #include <dpkg/dpkg.h>
 #include <dpkg/dpkg-db.h>
 #include <dpkg/arch.h>
@@ -58,8 +58,8 @@
 static void DPKG_ATTR_NORET
 printversion(const struct cmdinfo *ci, const char *value)
 {
-  printf(_("Debian `%s' package management program version %s.\n"),
-         DPKG, DPKG_VERSION_ARCH);
+  printf(_("Debian '%s' package management program version %s.\n"),
+         DPKG, PACKAGE_RELEASE);
   printf(_(
 "This is free software; see the GNU General Public License version 2 or\n"
 "later for copying conditions. There is NO warranty.\n"));
@@ -101,7 +101,7 @@ usage(const struct cmdinfo *ci, const char *value)
 "  --forget-old-unavail             Forget uninstalled unavailable pkgs.\n"
 "  -s|--status <package> ...        Display package status details.\n"
 "  -p|--print-avail <package> ...   Display available version details.\n"
-"  -L|--listfiles <package> ...     List files `owned' by package(s).\n"
+"  -L|--listfiles <package> ...     List files 'owned' by package(s).\n"
 "  -l|--list [<pattern> ...]        List packages concisely.\n"
 "  -S|--search <pattern> ...        Find package(s) owning file(s).\n"
 "  -C|--audit [<package> ...]       Check for broken package(s).\n"
@@ -120,8 +120,9 @@ usage(const struct cmdinfo *ci, const char *value)
 "\n"));
 
   printf(_(
-"Use dpkg -b|--build|-c|--contents|-e|--control|-I|--info|-f|--field|\n"
-" -x|--extract|-X|--vextract|--fsys-tarfile  on archives (type %s --help).\n"
+"Use dpkg with -b, --build, -c, --contents, -e, --control, -I, --info,\n"
+"  -f, --field, -x, --extract, -X, --vextract, --ctrl-tarfile, --fsys-tarfile\n"
+"on archives (type %s --help).\n"
 "\n"), BACKEND);
 
   printf(_(
@@ -633,7 +634,7 @@ set_force(const struct cmdinfo *cip, const char *value)
         break;
 
     if (!fip->name) {
-      badusage(_("unknown force/refuse option `%.*s'"),
+      badusage(_("unknown force/refuse option '%.*s'"),
                (int)min(l, 250), value);
     } else if (strcmp(fip->name, "all") == 0) {
       for (fip = forceinfos; fip->name; fip++)
@@ -642,7 +643,7 @@ set_force(const struct cmdinfo *cip, const char *value)
     } else if (fip->opt) {
       *fip->opt = cip->arg_int;
     } else {
-      warning(_("obsolete force/refuse option '%s'\n"), fip->name);
+      warning(_("obsolete force/refuse option '%s'"), fip->name);
     }
 
     if (!comma) break;
@@ -740,6 +741,7 @@ static const struct cmdinfo cmdinfos[]= {
   ACTIONBACKEND( "field",		'f', BACKEND),
   ACTIONBACKEND( "extract",		'x', BACKEND),
   ACTIONBACKEND( "vextract",		'X', BACKEND),
+  ACTIONBACKEND( "ctrl-tarfile",	0,   BACKEND),
   ACTIONBACKEND( "fsys-tarfile",	0,   BACKEND),
   { NULL,                0,   0, NULL,          NULL,      NULL,          0 }
 };
@@ -784,7 +786,7 @@ commandfd(const char *const *argv)
   infd = dpkg_options_parse_arg_int(cipaction, pipein);
   in = fdopen(infd, "r");
   if (in == NULL)
-    ohshite(_("couldn't open `%i' for stream"), (int) infd);
+    ohshite(_("couldn't open '%i' for stream"), (int)infd);
 
   for (;;) {
     bool mode = false;
@@ -793,7 +795,11 @@ commandfd(const char *const *argv)
 
     push_error_context();
 
-    do { c= getc(in); if (c == '\n') lno++; } while (c != EOF && isspace(c));
+    do {
+      c = getc(in);
+      if (c == '\n')
+        lno++;
+    } while (c != EOF && c_isspace(c));
     if (c == EOF) break;
     if (c == '#') {
       do { c= getc(in); if (c == '\n') lno++; } while (c != EOF && c != '\n');
@@ -806,10 +812,11 @@ commandfd(const char *const *argv)
       if (c == '\n') lno++;
 
       /* This isn't fully accurate, but overestimating can't hurt. */
-      if (isspace(c))
+      if (c_isspace(c))
         argc++;
     } while (c != EOF && c != '\n');
-    if (c == EOF) ohshit(_("unexpected eof before end of line %d"),lno);
+    if (c == EOF)
+      ohshit(_("unexpected end of file before end of line %d"), lno);
     if (!argc) continue;
     varbuf_end_str(&linevb);
     newargs = m_realloc(newargs, sizeof(const char *) * (argc + 1));
@@ -825,7 +832,7 @@ commandfd(const char *const *argv)
 	endptr--;
 	skipchar = true;
 	continue;
-      } else if (isspace(*ptr)) {
+      } else if (c_isspace(*ptr)) {
 	if (mode == true) {
 	  *ptr = '\0';
 	  mode = false;
